If you use `viprs` in your research, please cite the following paper(s):

> Zabad, S., Gravel, S., & Li, Y. (2023). **Fast and accurate Bayesian polygenic risk modeling with variational inference.** 
The American Journal of Human Genetics, 110(5), 741–761. https://doi.org/10.1016/j.ajhg.2023.03.009

## BibTeX records

```bibtex
@article{ZABAD2023741,
    title = {Fast and accurate Bayesian polygenic risk modeling with variational inference},
    journal = {The American Journal of Human Genetics},
    volume = {110},
    number = {5},
    pages = {741-761},
    year = {2023},
    issn = {0002-9297},
    doi = {https://doi.org/10.1016/j.ajhg.2023.03.009},
    url = {https://www.sciencedirect.com/science/article/pii/S0002929723000939},
    author = {Shadi Zabad and Simon Gravel and Yue Li}
}
```
